pub type ProtocolAggregationError = AggregationError;Expand description
Alias of MithrilStm:AggregationError.
Aliased Type
pub enum ProtocolAggregationError {
NotEnoughSignatures(u64, u64),
UnsupportedProofSystem(AggregateSignatureType),
IndexNotUnique,
MissingSnarkSignerData(u64),
MissingSnarkSignature(u64),
}Variants
NotEnoughSignatures(u64, u64)
Not enough signatures were collected, got this many instead.
UnsupportedProofSystem(AggregateSignatureType)
IndexNotUnique
There is a duplicate index
MissingSnarkSignerData(u64)
Signer registration data could not be found during witness assembly for SNARK prover input.
MissingSnarkSignature(u64)
A signature selected for witness assembly is missing its SNARK component.