pub struct CardanoBlocksTransactionsSigningConfig {
pub security_parameter: BlockNumberOffset,
pub step: BlockNumber,
}Expand description
Configuration for the signing of Cardano blocks and transactions
Fields
security_parameter: BlockNumberOffsetNumber of blocks to discard from the tip of the chain when importing blocks and transactions.
step: BlockNumberThe number of blocks between signature of the blocks and transactions.
Note: The step is adjusted to be a multiple of the block range length in order to guarantee that the block number signed in a certificate is effectively signed.
Implementations
Sourceimpl CardanoBlocksTransactionsSigningConfig
impl CardanoBlocksTransactionsSigningConfig
Sourcepub fn compute_block_number_to_be_signed(
&self,
block_number: BlockNumber,
) -> BlockNumber
pub fn compute_block_number_to_be_signed( &self, block_number: BlockNumber, ) -> BlockNumber
Compute the block number to be signed based on the chain tip block number.
The latest block number to be signed is the highest multiple of the step less or equal than the block number minus the security parameter.
The formula is as follows:
block_number = ⌊(tip.block_number - security_parameter) / step⌋ × step
where ⌊x⌋ is the floor function that rounds to the greatest integer less than or equal to x.