SignerWithStake

Struct SignerWithStake 

pub struct SignerWithStake {
    pub party_id: PartyId,
    pub verification_key_for_concatenation: ProtocolSignerVerificationKeyForConcatenation,
    pub verification_key_signature_for_concatenation: Option<ProtocolSignerVerificationKeySignatureForConcatenation>,
    pub operational_certificate: Option<ProtocolOpCert>,
    pub kes_evolutions: Option<KesEvolutions>,
    pub stake: Stake,
    pub verification_key_for_snark: Option<ProtocolSignerVerificationKeyForSnark>,
    pub verification_key_signature_for_snark: Option<ProtocolSignerVerificationKeySignatureForSnark>,
}
Signer represents a signing party in the network (including its stakes)

Fields

party_id: PartyId

The unique identifier of the signer

Used only for testing when SPO pool id is not certified

verification_key_for_concatenation: ProtocolSignerVerificationKeyForConcatenation

The verification key for the Concatenation proof system

verification_key_signature_for_concatenation: Option<ProtocolSignerVerificationKeySignatureForConcatenation>

The KES signature over the verification key for Concatenation

None is used only for testing when SPO pool id is not certified

operational_certificate: Option<ProtocolOpCert>

The operational certificate of stake pool operator attached to the signer node

None is used only for testing when SPO pool id is not certified

kes_evolutions: Option<KesEvolutions>

The number of evolutions of the KES key since the start KES period of the operational certificate at the time of signature.

stake: Stake

The signer stake

verification_key_for_snark: Option<ProtocolSignerVerificationKeyForSnark>
Available on crate feature future_snark only.

The verification key for the SNARK proof system

verification_key_signature_for_snark: Option<ProtocolSignerVerificationKeySignatureForSnark>
Available on crate feature future_snark only.

The KES signature over the verification key for SNARK (hex encoded)

Implementations

Source

impl SignerWithStake

pub fn from_signer(signer: Signer, stake: Stake) -> Self

Turn a Signer into a SignerWithStake.

pub fn without_snark_fields(self) -> Self

Available on crate feature future_snark only.

Remove SNARK-related fields for backward compatibility with older eras.

This clears the SNARK verification key and its KES signature, which is needed during eras that do not support SNARK proofs (e.g. Pythagoras) to ensure consistency between the signer’s initializer and the key registration entries.

pub fn strip_snark_fields(signers: Vec<Self>) -> Vec<Self>

Available on crate feature future_snark only.

Remove SNARK-related fields from a list of signers with stake for backward compatibility.

pub fn compute_hash(&self) -> String

Computes the hash of SignerWithStake