RegisterSignatureMessageHttp

Struct RegisterSignatureMessageHttp 

pub struct RegisterSignatureMessageHttp {
    pub signed_entity_type: SignedEntityType,
    pub party_id: PartyId,
    pub signature: HexEncodedSingleSignature,
    pub won_indexes: Vec<LotteryIndex>,
    pub signed_message: String,
}
Message structure to register single signature through HTTP.

Fields

signed_entity_type: SignedEntityType

Signed entity type

party_id: PartyId

The unique identifier of the signer

signature: HexEncodedSingleSignature

The single signature of the digest

won_indexes: Vec<LotteryIndex>

The indexes of the won lotteries that lead to the single signature

signed_message: String

Message that is signed by the signer

Used to buffer the signature for later if the aggregator has yet to create an open message for the signed entity type.