Module protocol

Module protocol 

Protocol module

This module contains types that standardize and make easier mithril protocol operations such as issuing single signatures, aggregating them as multi-signatures or computing aggregate verification keys.

Structs

MultiSigner
MultiSigner is the cryptographic engine in charge of producing multi-signatures from individual signatures
SignerBuilder
Allow to build Single Or Multi signers to generate a single signature or aggregate them
SingleSigner
The SingleSigner is the structure responsible for issuing SingleSignatures.

Enums

SignerBuilderError
SignerBuilder specific errors

Traits

ToMessage
Trait to convert a type to a message that can be signed or verified by the Mithril protocol.