pub struct MithrilFixture { /* private fields */ }Expand description
A fixture of Mithril data types.
Implementations
Sourceimpl MithrilFixture
impl MithrilFixture
Sourcepub fn new(
protocol_parameters: ProtocolParameters,
signers: Vec<SignerFixture>,
stake_distribution: ProtocolStakeDistribution,
) -> Self
pub fn new( protocol_parameters: ProtocolParameters, signers: Vec<SignerFixture>, stake_distribution: ProtocolStakeDistribution, ) -> Self
MithrilFixture factory.
Sourcepub fn protocol_parameters(&self) -> ProtocolParameters
pub fn protocol_parameters(&self) -> ProtocolParameters
Get the fixture protocol parameters.
Sourcepub fn signers_fixture(&self) -> Vec<SignerFixture>
pub fn signers_fixture(&self) -> Vec<SignerFixture>
Get the fixture signers.
Sourcepub fn signers_with_stake(&self) -> Vec<SignerWithStake>
pub fn signers_with_stake(&self) -> Vec<SignerWithStake>
Get the fixture signers with stake.
Sourcepub fn stake_distribution_parties(&self) -> Vec<StakeDistributionParty>
pub fn stake_distribution_parties(&self) -> Vec<StakeDistributionParty>
Get certificate metadata signers
Sourcepub fn stake_distribution(&self) -> StakeDistribution
pub fn stake_distribution(&self) -> StakeDistribution
Get the fixture stake distribution.
Sourcepub fn protocol_stake_distribution(&self) -> ProtocolStakeDistribution
pub fn protocol_stake_distribution(&self) -> ProtocolStakeDistribution
Get the fixture protocol stake distribution.
Sourcepub fn cardano_cli_stake_distribution(&self) -> CardanoCliStakeDistribution
pub fn cardano_cli_stake_distribution(&self) -> CardanoCliStakeDistribution
Get the stake distribution formated as a cardano-cli stake-snapshot output.
Note: will fail if the signers certification was disabled
Sourcepub fn compute_aggregate_verification_key(
&self,
) -> ProtocolAggregateVerificationKey
pub fn compute_aggregate_verification_key( &self, ) -> ProtocolAggregateVerificationKey
Compute the Aggregate Verification Key for this fixture.
Sourcepub fn compute_concatenation_aggregate_verification_key(
&self,
) -> ProtocolAggregateVerificationKeyForConcatenation
pub fn compute_concatenation_aggregate_verification_key( &self, ) -> ProtocolAggregateVerificationKeyForConcatenation
Compute the Aggregate Verification Key for concatenation for this fixture.
Sourcepub fn compute_and_encode_concatenation_aggregate_verification_key(
&self,
) -> HexEncodedAggregateVerificationKey
pub fn compute_and_encode_concatenation_aggregate_verification_key( &self, ) -> HexEncodedAggregateVerificationKey
Compute the Aggregate Verification Key for concatenation for this fixture and returns it has a HexEncodedAggregateVerificationKey.
Sourcepub fn compute_snark_aggregate_verification_key(
&self,
) -> Option<ProtocolAggregateVerificationKeyForSnark>
Available on crate feature future_snark only.
pub fn compute_snark_aggregate_verification_key( &self, ) -> Option<ProtocolAggregateVerificationKeyForSnark>
future_snark only.Compute the SNARK Aggregate Verification Key for this fixture, if available.
Sourcepub fn compute_and_encode_snark_aggregate_verification_key(
&self,
) -> Option<String>
Available on crate feature future_snark only.
pub fn compute_and_encode_snark_aggregate_verification_key( &self, ) -> Option<String>
future_snark only.Compute the SNARK Aggregate Verification Key for this fixture and returns it as a hex-encoded string.
Sourcepub fn create_genesis_certificate<T: Into<String>>(
&self,
network: T,
epoch: Epoch,
) -> Certificate
pub fn create_genesis_certificate<T: Into<String>>( &self, network: T, epoch: Epoch, ) -> Certificate
Create a genesis certificate using the fixture signers for the given beacon