pub struct SignerWithStake {
pub party_id: PartyId,
pub verification_key: ProtocolSignerVerificationKey,
pub verification_key_signature: Option<ProtocolSignerVerificationKeySignature>,
pub operational_certificate: Option<ProtocolOpCert>,
pub kes_evolutions: Option<KesEvolutions>,
pub stake: Stake,
}Expand description
Signer represents a signing party in the network (including its stakes)
Fields
party_id: PartyIdThe unique identifier of the signer
Used only for testing when SPO pool id is not certified
verification_key: ProtocolSignerVerificationKeyThe public key used to authenticate signer signature
verification_key_signature: Option<ProtocolSignerVerificationKeySignature>The encoded signer ‘Mithril verification key’ signature (signed by the Cardano node KES secret key)
None is used only for testing when SPO pool id is not certified
operational_certificate: Option<ProtocolOpCert>The encoded operational certificate of stake pool operator attached to the signer node
None is used only for testing when SPO pool id is not certified
kes_evolutions: Option<KesEvolutions>The number of evolutions of the KES key since the start KES period of the operational certificate at the time of signature.
stake: StakeThe signer stake
Implementations
Sourceimpl SignerWithStake
impl SignerWithStake
Sourcepub fn new(
party_id: PartyId,
verification_key: ProtocolSignerVerificationKey,
verification_key_signature: Option<ProtocolSignerVerificationKeySignature>,
operational_certificate: Option<ProtocolOpCert>,
kes_evolutions: Option<KesEvolutions>,
stake: Stake,
) -> SignerWithStake
pub fn new( party_id: PartyId, verification_key: ProtocolSignerVerificationKey, verification_key_signature: Option<ProtocolSignerVerificationKeySignature>, operational_certificate: Option<ProtocolOpCert>, kes_evolutions: Option<KesEvolutions>, stake: Stake, ) -> SignerWithStake
SignerWithStake factory
Sourcepub fn from_signer(signer: Signer, stake: Stake) -> Self
pub fn from_signer(signer: Signer, stake: Stake) -> Self
Turn a Signer into a SignerWithStake.
Sourcepub fn compute_hash(&self) -> String
pub fn compute_hash(&self) -> String
Computes the hash of SignerWithStake