ToMessage

Trait ToMessage 

pub trait ToMessage: Sync + Send {
    // Required method
    fn to_message(&self) -> String;
}
Trait to convert a type to a message that can be signed or verified by the Mithril protocol.

Required Methods

fn to_message(&self) -> String

Return a String representation of the message.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ToMessage for &str

Source

impl ToMessage for String

Implementors