pub trait ToMessage: Sync + Send {
// Required method
fn to_message(&self) -> String;
}Expand description
Trait to convert a type to a message that can be signed or verified by the Mithril protocol.
Required Methods
Sourcefn to_message(&self) -> String
fn to_message(&self) -> String
Return a String representation of the message.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".